@@ -1,21 +1,23 @@
 package PerlIO::Util;
 
+use 5.008_001;
+
 use strict;
 
-our $VERSION = '0.56';
+our $VERSION = '0.60';
 
 require XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
 
 *IO::Handle::get_layers = \&PerlIO::get_layers;
 
-sub open{
+sub open :method{
 	if(@_ < 3){
 		require Carp;
 		Carp::croak('Usage: PerlIO::Util->open($mode, @args)');
 	}
 	my $anonio;
-	unless(CORE::open $anonio, $_[1], @_[2 .. $#_]){
+	unless(open $anonio, $_[1], @_[2 .. $#_]){
 		require Carp;
 		Carp::croak('Cannot open(',join(', ', @_[1 .. $#_]), "): $!");
 	}
@@ -33,7 +35,7 @@ PerlIO::Util - A selection of general PerlIO utilities
 
 =head1 VERSION
 
-This document describes PerlIO::Util version 0.56
+This document describes PerlIO::Util version 0.60
 
 =head1 SYNOPSIS
 
@@ -41,19 +43,19 @@ This document describes PerlIO::Util version 0.56
 
     # utility layers
 
-    open $in, "+<:flock", ...; # with flock(IN, LOCK_EX)
+    open $in, '+<:flock', ...; # with flock(IN, LOCK_EX)
 
-    open $in, "+<:creat :excl", ...; # with O_CREAT | O_EXCL
+    open $in, '+<:creat :excl', ...; # with O_CREAT | O_EXCL
 
-    open $out, ">:tee", $file, \$scalar, \*STDERR;
-    print $out "foo"; # print to $file, $scalar and *STDERR
+    open $out, '>:tee', 'file.txt', \$scalar, \*STDERR;
+    print $out 'foo'; # print to 'file.txt', $scalar and *STDERR
 
     # utility routines
 
     $fh = PerlIO::Util->open('<', $file); # it dies on fail
 
     *STDOUT->push_layer(scalar => \$s); # it dies on fail
-    print "foo";
+    print 'foo';
 
     print *STDOUT->pop_layer(); # => scalar
     print $s; # => foo
@@ -88,7 +90,7 @@ See L<PerlIO::excl>.
 
 =head2 :tee
 
-Multiplex output layer.
+Multiplex output stream.
 
 See L<PerlIO::tee>.
 
@@ -100,7 +102,7 @@ See L<PerlIO::dir>.
 
 =head2 :reverse
 
-Reverse input iterator.
+Reverse input stream.
 
 See L<PerlIO::reverse>.
 
